==> rutorrent-3.9.tar.gz: ruTorrent-3.9/plugins/rss/lang/lv.js <==
﻿/*
 * PLUGIN RSS
 *
 * Latvian language file.
 *
 * Author: 
 */

 theUILang.addRSS			= "Add RSS Feed";
 theUILang.feedURL			= "Feed URL";
 theUILang.alias			= "Custom Alias";
 theUILang.rssAuto			= "Automatically download items published in feed";
 theUILang.allFeeds			= "All Feeds";
 theUILang.incorrectURL 		= "Please, specify correct URL feed."
 theUILang.cantFetchRSS 		= "Error loading feed.";
 theUILang.rssAlreadyExist		= "Feed already exists.";
 theUILang.rssDontExist 		= "Feed doesn't exist.";
 theUILang.rssCantLoadTorrent		= "Error loading torrent.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "Already loaded";
 theUILang.rssMenuLoad			= "Load";
 theUILang.rssMenuOpen			= "Open in Browser";
 theUILang.rssMenuClearHistory		= "Clear History";
 theUILang.rssMenuAddToFilter		= "Add to Favorites";
 theUILang.rssMenuManager		= "RSS Manager";
 theUILang.rssMenuRefresh		= "Update Feed";
 theUILang.rssMenuDisable		= "Disable Feed";
 theUILang.rssMenuEnable		= "Enable Feed";
 theUILang.rssMenuEdit			= "Edit Feed";
 theUILang.rssMenuDelete		= "Delete Feed";
 theUILang.rssDeletePrompt		= "Do you really want to delete selected feed?";
 theUILang.rssNewFilter 		= "New filter";
 theUILang.rssFilter			= "Filter";
 theUILang.rssAddFilter 		= "Add";
 theUILang.rssDelFilter 		= "Delete";
 theUILang.rssCheckFilter		= "?";
 theUILang.rssFiltersLegend		= "Filter settings";
 theUILang.rssIncorrectFilter		= "Filter is incorrect.";
 theUILang.foundedByFilter		= "Matches";
 theUILang.rssExclude			= "Exclude";
 theUILang.rssStatusError		= "Load error";
 theUILang.rssFeeds			= "Feeds";
 theUILang.rssCheckTitle		= "Check title field";
 theUILang.rssCheckDescription		= "Check description field";
 theUILang.rssCheckLink 		= "Check link field";
 theUILang.rssMinInterval		= "Min interval";
 theUILang.rssIntervalAlways		= "(match always)";
 theUILang.rssIntervalOnce		= "(match only once)";
 theUILang.rssInterval12h		= "12 hours";
 theUILang.rssInterval1d		= "1 day";
 theUILang.rssInterval2d		= "2 days";
 theUILang.rssInterval3d		= "3 days";
 theUILang.rssInterval4d		= "4 days";
 theUILang.rssInterval6d		= "6 days";
 theUILang.rssInterval1w		= "1 week";
 theUILang.rssInterval2w		= "2 weeks";
 theUILang.rssInterval3w		= "3 weeks";
 theUILang.rssInterval1m		= "1 month";
 theUILang.rssClearFilter		= "Reset";
 theUILang.rssMarkAs			= "Mark as";
 theUILang.rssAsLoaded			= "loaded";
 theUILang.rssAsUnloaded		= "unloaded";
 theUILang.addRSSGroup			= "Add RSS Group";
 theUILang.editRSSGroup 		= "Edit RSS Group";
 theUILang.addRSSGroupContent		= "Content";
 theUILang.rssMenuGroupDisable		= "Disable Group";
 theUILang.rssMenuGroupRefresh		= "Update Group";
 theUILang.rssMenuGroupEnable		= "Enable Group";
 theUILang.rssMenuGroupEdit		= "Edit Group";
 theUILang.rssMenuGroupDelete		= "Delete Group";
 theUILang.rssMenuGroupContentsDelete	= "Delete Contents";
 theUILang.rssDeleteGroupPrompt 	= "Do you really want to delete selected group?";
 theUILang.rssDeleteGroupContentsPrompt = "Do you really want to delete selected group with all contents?";
 theUILang.rssAllFiters 		= "All filters";
 theUILang.rssUpdateInterval 		= "Update interval";
 theUILang.Directories			= "Directories";
 theUILang.Labels			= "Labels";

thePlugins.get("rss").langLoaded();

==> rutorrent-4.3.6.tar.gz: ruTorrent-4.3.6/plugins/rss/lang/lv.js <==
﻿/*
 * PLUGIN RSS
 *
 * Latvian language file.
 *
 * Author: 
 */

 theUILang.addRSS			= "Add RSS Feed";
 theUILang.feedURL			= "Feed URL";
 theUILang.alias			= "Custom Alias";
 theUILang.rssAuto			= "Automatically download items published in feed";
 theUILang.allFeeds			= "All Feeds";
 theUILang.incorrectURL			= "Please, specify correct URL feed.";
 theUILang.cantFetchRSS			= "Error loading feed.";
 theUILang.rssAlreadyExist		= "Feed already exists.";
 theUILang.rssDontExist			= "Feed doesn't exist.";
 theUILang.rssCantLoadTorrent		= "Error loading torrent.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "Already loaded";
 theUILang.rssMenuLoad			= "Load";
 theUILang.rssMenuOpen			= "Open in Browser";
 theUILang.rssMenuClearHistory		= "Clear History";
 theUILang.rssMenuAddToFilter		= "Add to Favorites";
 theUILang.rssMenuManager		= "RSS Manager";
 theUILang.rssMenuRefresh		= "Update Feed";
 theUILang.rssMenuDisable		= "Disable Feed";
 theUILang.rssMenuEnable		= "Enable Feed";
 theUILang.rssMenuEdit			= "Edit Feed";
 theUILang.rssMenuDelete		= "Delete Feed";
 theUILang.rssDeletePrompt		= "Do you really want to delete selected feed?";
 theUILang.rssNewFilter			= "New filter";
 theUILang.rssFilter			= "Filter";
 theUILang.rssAddFilter			= "Add";
 theUILang.rssDelFilter			= "Delete";
 theUILang.rssCheckFilter		= "?";
 theUILang.rssFiltersLegend		= "Filter settings";
 theUILang.rssIncorrectFilter		= "Filter is incorrect.";
 theUILang.foundedByFilter		= "Matches";
 theUILang.rssExclude			= "Exclude";
 theUILang.rssStatusError		= "Load error";
 theUILang.rssFeeds			= "Feeds";
 theUILang.rssCheckTitle		= "Check title field";
 theUILang.rssCheckDescription		= "Check description field";
 theUILang.rssCheckLink			= "Check link field";
 theUILang.rssMinInterval		= "Min interval";
 theUILang.rssIntervalAlways		= "(match always)";
 theUILang.rssIntervalOnce		= "(match only once)";
 theUILang.rssInterval12h		= "12 hours";
 theUILang.rssInterval1d		= "1 day";
 theUILang.rssInterval2d		= "2 days";
 theUILang.rssInterval3d		= "3 days";
 theUILang.rssInterval4d		= "4 days";
 theUILang.rssInterval6d		= "6 days";
 theUILang.rssInterval1w		= "1 week";
 theUILang.rssInterval2w		= "2 weeks";
 theUILang.rssInterval3w		= "3 weeks";
 theUILang.rssInterval1m		= "1 month";
 theUILang.rssClearFilter		= "Reset";
 theUILang.rssMarkAs			= "Mark as";
 theUILang.rssAsLoaded			= "loaded";
 theUILang.rssAsUnloaded		= "unloaded";
 theUILang.addRSSGroup			= "Add RSS Group";
 theUILang.editRSSGroup			= "Edit RSS Group";
 theUILang.addRSSGroupContent		= "Content";
 theUILang.rssMenuGroupDisable		= "Disable Group";
 theUILang.rssMenuGroupRefresh		= "Update Group";
 theUILang.rssMenuGroupEnable		= "Enable Group";
 theUILang.rssMenuGroupEdit		= "Edit Group";
 theUILang.rssMenuGroupDelete		= "Delete Group";
 theUILang.rssMenuGroupContentsDelete	= "Delete Contents";
 theUILang.rssDeleteGroupPrompt		= "Do you really want to delete selected group?";
 theUILang.rssDeleteGroupContentsPrompt	= "Do you really want to delete selected group with all contents?";
 theUILang.rssAllFiters			= "All filters";
 theUILang.rssUpdateInterval		= "Update interval";
 theUILang.rssShowErrorsDelayed		= "Delay RSS error notification until the log tab or RSS feed is visible";
 theUILang.Directories			= "Directories";
 theUILang.Labels			= "Labels";

thePlugins.get("rss").langLoaded();
